@@ -1,7 +1,7 @@
 package Getopt::Long::EvenLess;
 
 our $DATE = '2017-01-11'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 # let's be minimalistic
 #use strict 'subs', 'vars';
@@ -212,7 +212,7 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.08 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2017-01-11.
+This document describes version 0.09 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2017-01-11.
 
 =head1 DESCRIPTION
 
@@ -229,7 +229,7 @@ Compared to GL and GLL, it:
 
 =over
 
-=item * minimum Configure() support
+=item * has minimum Configure() support
 
 Only these configurations are known: pass_through, no_pass_through (default).
 
@@ -274,23 +274,23 @@ handler, etc.
 
 B<Startup overhead>. Here's a sample startup overhead benchmark:
 
-                           Rate      run_gl     load_gl run_gl_less load_gl_less load_gl_evenless run_gl_evenless   perl
- run_gl            66.4+-0.64/s          --       -5.9%      -71.3%       -71.5%           -80.9%          -81.3% -89.6%
- load_gl          70.59+-0.16/s     6.3+-1%          --      -69.4%       -69.7%           -79.7%          -80.1% -89.0%
- run_gl_less         231+-1.1/s 247.9+-3.7% 227.3+-1.7%          --        -0.8%           -33.4%          -34.8% -64.0%
- load_gl_less      232.8+-1.9/s 250.6+-4.4% 229.8+-2.7% 0.78+-0.94%           --           -32.9%          -34.3% -63.7%
- load_gl_evenless    347+-9.7/s    423+-15%    392+-14%  50.2+-4.3%   49.1+-4.3%               --           -2.1% -45.9%
- run_gl_evenless     354.5+-4/s 433.9+-7.9% 402.2+-5.7%  53.4+-1.9%   52.3+-2.1%        2.2+-3.1%              -- -44.7%
- perl                641+-3.7/s    865+-11% 808.1+-5.6% 177.5+-2.1%  175.3+-2.7%       84.7+-5.3%      80.8+-2.3%     --
+                           Rate     load_gl      run_gl load_gl_less run_gl_less run_gl_evenless load_gl_evenless   perl
+ load_gl          69.66+-0.18/s          --       -0.4%       -68.6%      -69.2%          -82.2%           -82.7% -89.1%
+ run_gl            69.95+-0.2/s 0.42+-0.38%          --       -68.5%      -69.1%          -82.1%           -82.6% -89.0%
+ load_gl_less      222.1+-1.1/s 218.8+-1.8% 217.5+-1.8%           --       -1.9%          -43.3%           -44.8% -65.1%
+ run_gl_less       226.3+-1.9/s 224.9+-2.8% 223.6+-2.8%  1.92+-0.99%          --          -42.2%           -43.7% -64.4%
+ run_gl_evenless   391.6+-3.9/s 462.2+-5.8% 459.9+-5.8%     76.4+-2%    73+-2.2%              --            -2.6% -38.5%
+ load_gl_evenless    402+-1.1/s 477.1+-2.2% 474.6+-2.3%       81+-1%  77.6+-1.6%       2.6+-1.1%               -- -36.8%
+ perl              636.3+-6.1/s 813.5+-9.1% 809.6+-9.1%  186.5+-3.1% 181.1+-3.6%      62.5+-2.2%       58.3+-1.6%     --
  
  Average times:
-   perl            :     1.5601ms
-   run_gl_evenless :     2.8209ms
-   load_gl_evenless:     2.8818ms
-   load_gl_less    :     4.2955ms
-   run_gl_less     :     4.3290ms
-   load_gl         :    14.1663ms
-   run_gl          :    15.0602ms
+   perl            :     1.5716ms
+   load_gl_evenless:     2.4876ms
+   run_gl_evenless :     2.5536ms
+   run_gl_less     :     4.4189ms
+   load_gl_less    :     4.5025ms
+   run_gl          :    14.2959ms
+   load_gl         :    14.3554ms
 
 =head1 FUNCTIONS
 
